==> qtjambi-uic-5.15.18-sources.jar: io/qt/uic/ui4/DomSizeF.java <==
package io.qt.uic.ui4;

import io.qt.*;


/**
 * @hidden
 * <p>Java wrapper for Qt class <code>DomSizeF</code></p>
 */
public class DomSizeF extends QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    /**
     * <p>See <code>DomSizeF::<wbr/>DomSizeF()</code></p>
     */
    public DomSizeF(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSizeF instance);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>clearElementHeight()</code></p>
     */
    @QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>clearElementWidth()</code></p>
     */
    @QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>elementHeight()const</code></p>
     */
    @QtUninvokable
    public final double elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>elementWidth()const</code></p>
     */
    @QtUninvokable
    public final double elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native double elementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>hasElementHeight()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>hasElementWidth()const</code></p>
     */
    @QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>read(QXmlStreamReader&amp;)</code></p>
     */
    @QtUninvokable
    public final void read(io.qt.core.@StrictNonNull QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>setElementHeight(double)</code></p>
     */
    @QtUninvokable
    public final void setElementHeight(double a){
        setElementHeight_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementHeight_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>setElementWidth(double)</code></p>
     */
    @QtUninvokable
    public final void setElementWidth(double a){
        setElementWidth_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @QtUninvokable
    private native void setElementWidth_native_double(long __this__nativeId, double a);
    
    /**
     * <p>See <code>DomSizeF::<wbr/>write(QXmlStreamWriter&amp;,<wbr/>QString)const</code></p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer, java.lang.@NonNull String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected DomSizeF(QPrivateConstructor p) { super(p); } 
    
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @QtUninvokable
    public final void write(io.qt.core.@StrictNonNull QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
}

==> qtjambi-uic-6.4.2-sources.jar: io/qt/uic/ui4/DomSizeF.java <==
package io.qt.uic.ui4;


/**
 * <p>Java wrapper for Qt class DomSizeF</p>
 */
public class DomSizeF extends io.qt.QtObject
{
    static {
        QtJambi_LibraryUtilities.initialize();
    }
    
    
    public DomSizeF(){
        super((QPrivateConstructor)null);
        initialize_native(this);
    }
    
    private native static void initialize_native(DomSizeF instance);
    
    @io.qt.QtUninvokable
    public final void clearElementHeight(){
        clearElementHeight_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementHeight_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void clearElementWidth(){
        clearElementWidth_native(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native void clearElementWidth_native(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final double elementHeight(){
        return elementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native double elementHeight_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final double elementWidth(){
        return elementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native double elementWidth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementHeight(){
        return hasElementHeight_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementHeight_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final boolean hasElementWidth(){
        return hasElementWidth_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native boolean hasElementWidth_native_constfct(long __this__nativeId);
    
    @io.qt.QtUninvokable
    public final void read(io.qt.core.QXmlStreamReader reader){
        java.util.Objects.requireNonNull(reader, "Argument 'reader': null not expected.");
        read_native_ref_QXmlStreamReader(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(reader));
    }
    
    @io.qt.QtUninvokable
    private native void read_native_ref_QXmlStreamReader(long __this__nativeId, long reader);
    
    @io.qt.QtUninvokable
    public final void setElementHeight(double a){
        setElementHeight_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementHeight_native_double(long __this__nativeId, double a);
    
    @io.qt.QtUninvokable
    public final void setElementWidth(double a){
        setElementWidth_native_double(QtJambi_LibraryUtilities.internal.nativeId(this), a);
    }
    
    @io.qt.QtUninvokable
    private native void setElementWidth_native_double(long __this__nativeId, double a);
    
    /**
     * <p>Overloaded function for {@link #write(io.qt.core.QXmlStreamWriter, java.lang.String)}
     *  with <code>tagName = (String)null</code>.</p>
     */
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer) {
        write(writer, (String)null);
    }
    
    @io.qt.QtUninvokable
    public final void write(io.qt.core.QXmlStreamWriter writer, java.lang.String tagName){
        java.util.Objects.requireNonNull(writer, "Argument 'writer': null not expected.");
        write_native_ref_QXmlStreamWriter_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(writer), tagName);
    }
    
    @io.qt.QtUninvokable
    private native void write_native_ref_QXmlStreamWriter_cref_QString_constfct(long __this__nativeId, long writer, java.lang.String tagName);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected DomSizeF(QPrivateConstructor p) { super(p); } 
    
}
